
2023 MAR 13

*   Milestone: version `v0.0.0.dev28` was used for the published screencast: https://asciinema.org/a/566785
*   Show FS_71_87_33_52 `help_hint` for completion arg.
*   `Alt+Shift+Q` output (FS_02_25_41_81 `query_enum_items_func`):
    *   Show consumed args.
    *   Display `found_count`.
